/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.allocation;

import java.util.HashMap;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.RootEditPart;

/**
 * Implementation of {@link IAllocationPositionService}. Stores the layout information of all
 * allocation diagrams.
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class AllocationPositionService implements IAllocationPositionService {

	/** Map which stores the layout information of a (Allocation) Root Edit Part. */
	HashMap<RootEditPart, AllocationPosBounds> posBounds = new HashMap<>();

	/** 'Struct' to store the layout information of an allocation diagram. */
	private class AllocationPosBounds {
		/** Stores the bounds of the source of the allocation in the editor. */
		public Rectangle sourceAllocationBounds = new Rectangle();

		/** Stores the bounds of the target of the allocation in the editor. */
		public Rectangle targetAllocationBounds = new Rectangle();

		/** Stores the position of the top left most element of all source elements */
		public Point minSourcePos = new Point();

		/** Stores the position of the top left most element of all target elements */
		public Point minTargetPos = new Point();
	}

	/** {@inheritDoc} */
	@Override
	public Point getMinSourcePos(RootEditPart root) {
		return checkAndCreate(root).minSourcePos;
	}

	/** {@inheritDoc} */
	@Override
	public Point getMinTargetPos(RootEditPart root) {
		return checkAndCreate(root).minTargetPos;
	}

	/** {@inheritDoc} */
	@Override
	public Rectangle getSourceAllocationBounds(RootEditPart root) {
		return checkAndCreate(root).sourceAllocationBounds;
	}

	/** {@inheritDoc} */
	@Override
	public Rectangle getTargetAllocationBounds(RootEditPart root) {
		return checkAndCreate(root).targetAllocationBounds;
	}

	/** {@inheritDoc} */
	@Override
	public void setMinSourcePos(RootEditPart root, Point point) {
		AllocationPosBounds allocationPosBounds = checkAndCreate(root);
		allocationPosBounds.minSourcePos = point;

	}

	/** {@inheritDoc} */
	@Override
	public void setMinTargetPos(RootEditPart root, Point point) {
		AllocationPosBounds allocationPosBounds = checkAndCreate(root);
		allocationPosBounds.minTargetPos = point;
	}

	/** {@inheritDoc} */
	@Override
	public void setSourceAllocationBounds(RootEditPart root, Rectangle bounds) {
		AllocationPosBounds allocationPosBounds = checkAndCreate(root);
		allocationPosBounds.sourceAllocationBounds = bounds;
	}

	/** {@inheritDoc} */
	@Override
	public void setTargetAllocationBounds(RootEditPart root, Rectangle bounds) {
		AllocationPosBounds allocationPosBounds = checkAndCreate(root);
		allocationPosBounds.targetAllocationBounds = bounds;
	}

	/** Check if bounds exist for this edit part and otherwise create them. */
	private AllocationPosBounds checkAndCreate(RootEditPart root) {
		AllocationPosBounds allocationPosBounds = posBounds.get(root);
		if(allocationPosBounds == null) {
			AllocationPosBounds newObject = new AllocationPosBounds();
			posBounds.put(root, newObject);
			return newObject;
		}
		return allocationPosBounds;
	}

}
