/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.annotation;

import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.kernel.utils.KernelModelElementUtils;

/**
 * Service used to retrieve and instantiate model element annotations.
 * 
 * @author eder, barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 79A7E219A9B6A3BC2630A144BC69871B
 */
public interface IAnnotationValueService {

	/** Singleton instance of {@link IAnnotationValueService}. */
	public static final IAnnotationValueService INSTANCE = new AnnotationValueService();

	/**
	 * <p>
	 * Returns an {@link AnnotationEntry} that contains all {@link IAnnotatedSpecification}s that
	 * have been registered for the given {@link IModelElement}. In case any these do not exist yet
	 * for the given {@code modelElement}, they are instantiated.
	 * </p>
	 * 
	 * <p>
	 * Implementations of this method shall use
	 * {@link KernelModelElementUtils#runAsCommand(org.eclipse.emf.ecore.EObject, Runnable)} and
	 * hence are safe to be called from the GUI context.
	 * </p>
	 */
	public AnnotationEntry getAnnotationEntry(IModelElement element);

	/**
	 * <p>
	 * If required, instantiate annotation for the given model element.
	 * </p>
	 * 
	 * <p>
	 * <b>CAVEAT: </b>This method must be called from a context that allows the modification of the
	 * model. In contrast to {@link #getAnnotationEntry(IModelElement)}, the caller of this method
	 * is responsible for ensuring this pre-condition.
	 * </p>
	 */
	public void instantiateAnnotations(IModelElement element);

}
