/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui;

import static java.lang.System.mapLibraryName;
import static org.eclipse.core.runtime.FileLocator.toFileURL;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: BB5C03A907DC8D5F1D43B5F8969A891C
 */
public class ToolingGraphicsGLUIActivator extends AbstractUIPlugin {

	/** The plug-in ID. */
	public static final String PLUGIN_ID = ToolingGraphicsGLUIActivator.class.getPackage()
			.getName(); //$NON-NLS-1$

	/** The shared instance. */
	private static ToolingGraphicsGLUIActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;

		System.out.println("Preloading native LWJGL libraries.");

		// preload JEMALLOC
		String jemallocLibPath = loadPluginLocalLibrary(getBundle(), "/lib", "jemalloc");
		System.out.println("LWJGL jemalloc library path = " + jemallocLibPath);
		// LWJGL has its own System.load() call when this property is provided
		System.setProperty("org.lwjgl.system.jemalloc.libname", jemallocLibPath);

		// preload LWJGL
		String lwjglLibPath = loadPluginLocalLibrary(getBundle(), "/lib", "lwjgl");
		System.out.println("LWJGL lwjgl library path = " + lwjglLibPath);
		System.out.println("Done preloading native LWJGL libraries.");
	}

	/** Load the given local library using {@link System#load(String)}. */
	private String loadPluginLocalLibrary(Bundle bundle, String bundleLocalLibraryFolder,
			String libraryName) throws Exception {
		String osLibName = mapLibraryName(libraryName);
		String fullPath =
				toFileURL(bundle.getEntry(bundleLocalLibraryFolder)).getPath() + osLibName;
		System.load(fullPath);
		return fullPath;
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/** Returns the shared instance. */
	public static ToolingGraphicsGLUIActivator getDefault() {
		return plugin;
	}

	/** Returns the image descriptor for the given icon file. */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}
}
