/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.xmlmodel;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Base class for model elements that wrap XML elements from architecture files.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 7CFB515CCB5CDA1B468234F615FE6E9F
 */
public abstract class ElementBase<T extends XmlRootModelBase> {

	/** XML element wrapped by this model element */
	protected final Element domNode;

	/** Model this model element belongs to */
	protected final T model;

	/** Constructor */
	protected ElementBase(Element domNode, T model) {
		this.domNode = domNode;
		this.model = model;
	}

	/** Removes this from the model */
	public void remove() {
		domNode.getParentNode().removeChild(domNode);
		model.fireModelChanged();
	}

	/** Moves this element up in the XML. */
	public void moveUp() {
		Node previous = domNode.getPreviousSibling();

		// skip additional non-element nodes (for example comments)
		while (previous != null && previous.getNodeType() != Node.ELEMENT_NODE) {
			previous = previous.getPreviousSibling();
		}

		if (previous != null) {
			moveBefore(previous);
		}
	}

	/** Moves this element down in the XML. */
	public void moveDown() {
		Node next = domNode.getNextSibling();

		// skip additional non-element nodes (for example comments)
		while (next != null && next.getNodeType() != Node.ELEMENT_NODE) {
			next = next.getNextSibling();
		}

		if (next != null) {
			moveBefore(next.getNextSibling());
		}
	}

	/**
	 * Moves the XML node that this element wraps before another node. If that
	 * other node is null, domNode is moved to the end of the node list.
	 */
	private void moveBefore(Node node) {
		Node parentNode = domNode.getParentNode();
		parentNode.insertBefore(domNode, node);
		model.fireModelChanged();
	}

	/** Returns the model this belongs to. */
	public T getModel() {
		return model;
	}

	/** Returns the DOM node. */
	public Element getDomNode() {
		return domNode;
	}

	/** Returns the name of this element. */
	public abstract String getName();
}